<img src="https://github.com/pyviz/pyviz/blob/master/doc/_static/pyviz-logo.png"><br>

-----------------

# PyViz: How to solve visualization problems with Python tools

|    |    |
| --- | --- |
| Build Status | [![Linux/MacOS Build Status](https://travis-ci.org/pyviz/pyviz.svg?branch=master)](https://travis-ci.org/pyviz/pyviz) [![Windows Build status](https://img.shields.io/appveyor/ci/pyviz/pyviz/master.svg?logo=appveyor)](https://ci.appveyor.com/project/pyviz/pyviz/branch/master) |
| Latest dev release | [![Github tag](https://img.shields.io/github/tag/pyviz/pyviz.svg?label=tag&colorB=11ccbb)](https://github.com/pyviz/pyviz/tags) |
| Latest release | [![Github release](https://img.shields.io/github/release/pyviz/pyviz.svg?label=tag&colorB=11ccbb)](https://github.com/pyviz/pyviz/releases) [![PyPI version](https://img.shields.io/pypi/v/pyviz.svg?colorB=cc77dd)](https://pypi.python.org/pypi/pyviz) [![pyviz version](https://img.shields.io/conda/v/pyviz/pyviz.svg?colorB=4488ff&style=flat)](https://anaconda.org/pyviz/pyviz) [![conda-forge version](https://img.shields.io/conda/v/conda-forge/pyviz.svg?label=conda%7Cconda-forge&colorB=4488ff)](https://anaconda.org/conda-forge/pyviz) [![defaults version](https://img.shields.io/conda/v/anaconda/pyviz.svg?label=conda%7Cdefaults&style=flat&colorB=4488ff)](https://anaconda.org/anaconda/pyviz) |
| Docs | [![gh-pages](https://img.shields.io/github/last-commit/pyviz/pyviz/gh-pages.svg)](https://github.com/pyviz/pyviz/tree/gh-pages) [![site](https://img.shields.io/website-up-down-green-red/http/pyviz.org.svg)](http://pyviz.org) |
| Dependencies | [![](https://img.shields.io/website-up-down-green-red/http/status.pyviz.org.svg?label=status-dashboard)](http://status.pyviz.org/) |


## What is it?	     

This repository provides examples, demos, and training materials
documenting how to solve visualization problems using Python
tools that work with web browsers, including
[Bokeh](https://bokeh.pydata.org),
[HoloViews](https://holoviews.org),
[GeoViews](http://geoviews.org),
[Matplotlib](https://matplotlib.org),
[Datashader](https://github.com/pyviz/datashader), and
[Param](https://github.com/pyviz/param).

It includes a shared conda environment that ensures all these tools work together,
facilities for downloading sample data for use with these tools, and provides
starting points for solving your own visualization problems.


## Installation

See [pyviz.org](http://pyviz.org/installation.html) (or doc/installation.rst for a github clone).


## About pyviz.org

PyViz is a project supported in part by [Anaconda](https://anaconda.com).
All projects used here are freely available for commercial or
non-commercial use according to a permissive open-source license as
described in each project's website.
